@@ -505,19 +505,20 @@ class Jira(AtlassianRestAPI):
         url = 'rest/api/2/issue/{}/worklog'.format(key)
         return self.post(url, data=worklog)
 
-    def issue_worklog(self, key, started, time_sec):
+    def issue_worklog(self, key, started, time_sec, comment=None):
         """
-
         :param key:
         :param time_sec: int: second
         :param started:
+        :param comment:
         :return:
         """
         data = {
-            # "comment": "Work on {}".format(key),
             "started": started,
             "timeSpentSeconds": time_sec
         }
+        if comment:
+            data['comment'] = comment
         return self.issue_add_json_worklog(key=key, worklog=data)
 
     def issue_field_value(self, key, field):
@@ -1485,7 +1486,7 @@ class Jira(AtlassianRestAPI):
         Provide a holiday scheme
         :return:
         """
-        url = 'rest/tempo-core/2/holidayschemes/{}/member/{}'.format(scheme_id, username)
+        url = 'rest/tempo-core/2/holidayschemes/{}/member/{}/'.format(scheme_id, username)
         data = {'id': scheme_id}
         return self.put(url, data=data)
 
@@ -1536,6 +1537,53 @@ class Jira(AtlassianRestAPI):
             params['groupBy'] = group_by
         return self.get(url, params=params)
 
+    def tempo_timesheets_get_worklogs(self, date_from=None, date_to=None, username=None, project_key=None,
+                                      account_key=None, team_id=None):
+        """
+
+        :param date_from: yyyy-MM-dd
+        :param date_to: yyyy-MM-dd
+        :param username: name of the user you wish to get the worklogs for
+        :param project_key: key of a project you wish to get the worklogs for
+        :param account_key: key of an account you wish to get the worklogs for
+        :param team_id: id of the Team you wish to get the worklogs for
+        :return:
+        """
+        params = {}
+        if date_from:
+            params['dateFrom'] = date_from
+        if date_to:
+            params['dateTo'] = date_to
+        if username:
+            params['username'] = username
+        if project_key:
+            params['projectKey'] = project_key
+        if account_key:
+            params['accountKey'] = account_key
+        if team_id:
+            params['teamId'] = team_id
+        url = 'rest/tempo-timesheets/3/worklogs/'
+        return self.get(url, params=params)
+
+    def tempo_timesheets_write_worklog(self, worker, started, time_spend_in_seconds, issue_id, comment=None):
+        """
+
+        :param comment:
+        :param worker:
+        :param started:
+        :param time_spend_in_seconds:
+        :param issue_id:
+        :return:
+        """
+        data = {"worker": worker,
+                "started": started,
+                "timeSpentSeconds": time_spend_in_seconds,
+                "originTaskId": str(issue_id)}
+        if comment:
+            data['comment'] = comment
+        url = 'rest/tempo-timesheets/4/worklogs/'
+        return self.post(url, data=data)
+
     def tempo_get_links_to_project(self, project_id):
         """
         Gets all links to a specific project
@@ -1589,6 +1637,25 @@ class Jira(AtlassianRestAPI):
         url = 'rest/tempo-teams/2/team/{}/member/{}/membership/{}'.format(team_id, member_id, membership_id)
         return self.delete(url)
 
+    def tempo_teams_update_member_information(self, team_id, member_id, membership_id, data):
+        """
+        Update team membership attribute info
+        :param team_id:
+        :param member_id:
+        :param membership_id:
+        :return:
+        """
+        url = 'rest/tempo-teams/2/team/{}/member/{}/membership/{}'.format(team_id, member_id, membership_id)
+        return self.put(url, data=data)
+
+    def tempo_timesheets_get_period_configuration(self):
+        return self.get('rest/tempo-timesheets/3/period-configuration')
+
+    def tempo_timesheets_get_private_configuration(self):
+        return self.get('rest/tempo-timesheets/3/private/config')
+
+    def tempo_teams_get_memberships_for_member(self, username):
+        return self.get('rest/tempo-teams/2/user/{}/memberships'.format(username))
     """
     #######################################################################
     #   Agile(Formerly Greenhopper) REST API implements                  #
